package net.sf.sit.candidate.impl;

import java.lang.reflect.Method;
import java.util.ArrayList;
import java.util.Collection;

import net.sf.sit.candidate.Matcher;
import net.sf.sit.candidate.Selector;
import net.sf.sit.support.Candidate;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Selects candidates by matching them with a {@link Matcher}.
 */
public class MatchingSelector implements Selector {

	private Matcher matcher;
	private final Logger log = LoggerFactory.getLogger(MatchingSelector.class);

	/**
	 * Default constructor.
	 */
	public MatchingSelector() {
	}

	/**
	 * Full constructor.
	 * 
	 * @param matcher
	 *            Matcher to match candidates
	 */
	public MatchingSelector(Matcher matcher) {
		this.matcher = matcher;
	}

	public Collection<Candidate> select(Collection<Object> providers,
			Method facadeMethod) {
		log.debug("Selecting candidates for facade method: {}", facadeMethod);
		ArrayList<Candidate> candidates = new ArrayList<Candidate>();
		for (Object provider : providers) {
			Class<?> candidateType = provider.getClass();
			Method[] methods = candidateType.getMethods();
			for (int methodIndex = 0; methodIndex < methods.length; methodIndex++) {
				Method method = methods[methodIndex];
				if (getMatcher().matches(facadeMethod, method)) {
					Candidate candidate = new Candidate(method, provider);
					log.debug("Adding matching candidate: {}", candidate);
					candidates.add(candidate);
				}
			}
		}
		return candidates;
	}

	public Matcher getMatcher() {
		return matcher;
	}

	/**
	 * Set matcher.
	 * 
	 * @param matcher
	 *            Matcher
	 */
	public void setMatcher(Matcher matcher) {
		this.matcher = matcher;
	}

}
