package net.sf.sit.validator.impl;

import javax.validation.ConstraintViolation;
import javax.validation.Path;
import javax.validation.constraints.NotNull;
import javax.validation.metadata.ConstraintDescriptor;

/**
 * A simplistic {@link ConstraintViolation} for method argument with null value
 * annotated as {@link NotNull}.
 */
@SuppressWarnings("rawtypes")
public class NullArgumentConstraintViolation implements ConstraintViolation {

	private final Class<?> rootBeanClass;
	private final Path propertyPath;

	/**
	 * Default constructor.
	 * 
	 * @param rootBeanClass
	 * @param argIndex
	 */
	public NullArgumentConstraintViolation(Class<?> rootBeanClass, int argIndex) {
		this.rootBeanClass = rootBeanClass;
		this.propertyPath = new ArgumentPath(argIndex);
	}

	public String getMessage() {
		return "{javax.validation.constraints.NotNull.message}";
	}

	public String getMessageTemplate() {
		return getMessage();
	}

	public Class<?> getRootBeanClass() {
		return rootBeanClass;
	}

	public Path getPropertyPath() {
		return propertyPath;
	}

	public Object getLeafBean() {
		return null;
	}

	public Object getInvalidValue() {
		return null;
	}

	public ConstraintDescriptor<?> getConstraintDescriptor() {
		return null;
	}

	public Object getRootBean() {
		return null;
	}

}
