package net.sf.sit.values;

/**
 * Converts a value to a required target type.
 */
public interface Converter {

	/**
	 * Convert a value to a given target type. When target type is a Collection,
	 * the required component type of the Collection is given.
	 * 
	 * @param targetType
	 *            Required target type to convert the source value to
	 * @param sourceValue
	 *            Source value to be converted
	 * @param targetComponentTypeHint
	 *            Hint for required target component type, needed in case the
	 *            target type is Collection
	 * @return Converted value
	 */
	<TT> TT convert(Class<TT> targetType, Object sourceValue,
			Class<?> targetComponentTypeHint);

}
