package net.sf.sit.values.impl;

import java.lang.reflect.Method;
import java.util.Arrays;

import net.sf.sit.values.Mapper;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Maps a source array of values to a target array of values by filling it with
 * the last source value.
 * <p>
 * Creates the target array of values of the required target length and fills
 * all target values with the last source value.
 */
public class FillByLastMapper implements Mapper {

	private final Logger log = LoggerFactory.getLogger(FillByLastMapper.class);

	public FillByLastMapper() {
	}

	public Object[] map(Object[] values, int targetLength, Method targetMethod) {
		log.debug("Mapping source values {} to target length {}", values,
				targetLength);
		Object[] targetValues = createArrayOfLength(getLast(values),
				targetLength);
		log.debug("Mapped target values: {}", targetValues);
		return targetValues;
	}

	private Object getLast(Object[] values) {
		if (null == values || 0 == values.length)
			return null;
		return values[values.length - 1];
	}

	private Object[] createArrayOfLength(Object fill, int targetLength) {
		Object[] result = new Object[targetLength];
		Arrays.fill(result, fill);
		return result;
	}

}
