package net.sf.sit.values.impl;

import java.lang.reflect.Method;

import net.sf.sit.values.Mapper;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Maps a source array of values to a target array of values by padding it with
 * the last source value.
 * <p>
 * First copies the source values into target values up to target length or
 * source length, whichever is smaller.
 * <p>
 * If the target length requested is bigger than source length, then pads target
 * values with the last source value.
 */
public class PadWithLastMapper implements Mapper {

	private final Logger log = LoggerFactory.getLogger(PadWithLastMapper.class);

	/**
	 * Default constructor.
	 */
	public PadWithLastMapper() {
	}

	public Object[] map(Object[] values, int targetLength, Method targetMethod) {
		log.debug("Mapping source values {} to target length {}", values,
				targetLength);
		Object[] mappedValues = copyArrayAdjustLength(values, targetLength);
		log.debug("Mapped target values: {}", mappedValues);
		return mappedValues;
	}

	private Object[] copyArrayAdjustLength(Object[] values, int targetLength) {
		Object[] result = new Object[targetLength];
		Object pad = null;
		if (null != values && values.length > 0)
			pad = values[values.length - 1];
		for (int i = 0; i < result.length; i++) {
			if (null != values && i < values.length)
				result[i] = values[i];
			else
				result[i] = pad;
		}
		return result;
	}

}
